@@ -1,12 +1,11 @@
 from abc import ABCMeta, abstractmethod
 
+
 class ToolGateway(metaclass=ABCMeta):
     @abstractmethod
     def run_tool(self, config_tool, folders_to_scan, **kwargs):
         "run_tool"
 
-    @classmethod
-    def get_iac_context_from_results(
-        self, path_file_results
-    ) -> None:
-        "get_iac_context_from_results"
\ No newline at end of file
+    @abstractmethod
+    def get_iac_context_from_results(self, path_file_results) -> None:
+        "get_iac_context_from_results"
